==> cli-0.26.0.tar.gz: cli-0.26.0/docs/cmd/tkn_taskrun_export.md <==
## tkn taskrun export

Export TaskRun

### Usage

```
tkn taskrun export
```

### Synopsis

Export TaskRun

### Examples

Export Taskrun Definition:

	"tkn taskrun export" will export a taskrun definition as yaml to be easily
	imported or modified.

	Example: export a TaskRun named 'taskrun' in namespace 'foo' and recreate
	it in the namespace 'bar':

    tkn taskrun export taskrun -n foo|kubectl create -f- -n bar


### Options

```
      --allow-missing-template-keys   If true, ignore any errors in templates when a field or map key is missing in the template. Only applies to golang and jsonpath output formats. (default true)
  -h, --help                          help for export
  -o, --output string                 Output format. One of: json|yaml|name|go-template|go-template-file|template|templatefile|jsonpath|jsonpath-as-json|jsonpath-file.
      --show-managed-fields           If true, keep the managedFields when printing objects in JSON or YAML format.
      --template string               Template string or path to template file to use when -o=go-template, -o=go-template-file. The template format is golang templates [http://golang.org/pkg/text/template/#pkg-overview].
```

### Options inherited from parent commands

```
  -c, --context string      name of the kubeconfig context to use (default: kubectl config current-context)
  -k, --kubeconfig string   kubectl config file (default: $HOME/.kube/config)
  -n, --namespace string    namespace to use (default: from $KUBECONFIG)
  -C, --no-color            disable coloring (default: false)
```

### SEE ALSO

* [tkn taskrun](tkn_taskrun.md)	 - Manage TaskRuns

==> cli-0.30.1.tar.gz: cli-0.30.1/docs/cmd/tkn_taskrun_export.md <==
## tkn taskrun export

Export TaskRun

### Usage

```
tkn taskrun export
```

### Synopsis

Export TaskRun

### Examples

Export Taskrun Definition:

	"tkn taskrun export" will export a taskrun definition as yaml to be easily
	imported or modified.

	Example: export a TaskRun named 'taskrun' in namespace 'foo' and recreate
	it in the namespace 'bar':

    tkn taskrun export taskrun -n foo|kubectl create -f- -n bar


### Options

```
      --allow-missing-template-keys   If true, ignore any errors in templates when a field or map key is missing in the template. Only applies to golang and jsonpath output formats. (default true)
  -h, --help                          help for export
  -o, --output string                 Output format. One of: (json, yaml, name, go-template, go-template-file, template, templatefile, jsonpath, jsonpath-as-json, jsonpath-file).
      --show-managed-fields           If true, keep the managedFields when printing objects in JSON or YAML format.
      --template string               Template string or path to template file to use when -o=go-template, -o=go-template-file. The template format is golang templates [http://golang.org/pkg/text/template/#pkg-overview].
```

### Options inherited from parent commands

```
  -c, --context string      name of the kubeconfig context to use (default: kubectl config current-context)
  -k, --kubeconfig string   kubectl config file (default: $HOME/.kube/config)
  -n, --namespace string    namespace to use (default: from $KUBECONFIG)
  -C, --no-color            disable coloring (default: false)
```

### SEE ALSO

* [tkn taskrun](tkn_taskrun.md)	 - Manage TaskRuns
